@@ -3,9 +3,12 @@ import unittest
 from almapiwrapper.users import User, NewUser, Fee
 from almapiwrapper.record import JsonData
 from almapiwrapper import config_log
+import os
 
 config_log("test.log")
 
+if os.getcwd().endswith('test'):
+    os.chdir('..')
 
 class TestCreateUser(unittest.TestCase):
 
